Welcome to COMET’s documentation! — Comet 0.1 documentation

# Welcome to COMET’s documentation!

Contributors: | Alex Eggemeier, Benjamin Camacho-Quevedo, Andrea Pezzotta, Martin Crocce, Román Scoccimarro, Ariel G. Sánchez
Source: | Source code at GitLab
Documentation: | Documentation at Readthedocs
Installation: | `pip install comet-emu`
References: | Eggemeier et al. 2022

💫 COMET - Cosmological Observables Modelled by Emulated perturbation Theory

  COMET is a Python package that provides emulated predictions of large-scale structure observables from models that are based on perturbation theory. COMET substantially speeds up these analytic computations without any relevant sacrifice in accuracy, enabling an extremely efficient exploration of large-scale structure likelihoods.

  At its core, COMET exploits the evolution mapping approach of Sanchez 2020 and Sanchez et al. 2021, which gives it a high degree of flexibility and allows it to cover a wide cosmology parameter space at continuous redshifts up to \(z \sim 3\). Specifically, the current release of COMET supports the following parameters (for more details, see here):

  Phys. cold dark matter density | \(\omega_c\)
  Phys. baryon density | \(\omega_b\)
  Scalar spectral index | \(n_s\)
  Hubble expansion rate | \(h\)
  Amplitude of scalar fluctuations | \(A_s\)
  Constant dark energy equation of state parameter | \(w_0\)
  Time-evolving equation of state parameter | \(w_a\)
  Curvature density parameter | \(\Omega_K\)

  Currently, COMET can be used to obtain the following quantities (the perturbation theory models are described here):

  - the real-space galaxy power spectrum at one-loop order and bispectrum at tree-level order

  - multipoles (monopole, quadrupole, hexadecapole) of the redshift-space power spectrum at one-loop order and bispectrum at tree-level order for two different redshift-space distortion models

  - the linear matter power spectrum (with and without infrared resummation)

  - Gaussian covariance matrices for the real-space power spectrum and bispectrum and their redshift-space multipoles

  - \(\chi^2\)’s for arbitrary combinations of multipoles

  COMET provides an easy-to-use interface for all of these computations, and we give quick-start as well as more in-depth examples on our tutorial pages.

  Our package is made publicly available under the MIT licence; please cite the papers listed above if you are making use of COMET in your own work.

Note

The COMET emulator is under constant development and new versions of the emulator become available as we improve them. Follow our public repository to make sure you are always up to date with our latest release.

Contents:

- Installation
- Tutorials
  - Quick-start
  - Advanced configuration options
  - Beyond \(P_{\ell}\) predictions
  - Covariance matrices
  - Binning and discreteness effects
  - Working with data sets
- Model Description
  - Real-space matter power spectrum
  - Real-space galaxy power spectrum
  - Redshift-space galaxy power spectrum
  - Legendre multipoles and geometrical distortions
- Parameter space
  - Ranges of emulated parameters
  - Cosmological parameters
  - Bias and RSD parameters

Complete API:

- comet
  - PTEmu
  - bispectrum
  - cosmology
  - data
  - tables

# Indices and tables

- Index

- Module Index

- Search Page